
.. image:: https://github.com/jamesssooi/fonty/raw/master/artwork/logo.png
      :alt: Logo of fonty
      :width: 300px
      :align: center

.. image:: https://raw.githubusercontent.com/jamesssooi/fonty/master/artwork/hero.png
      :alt: Screenshot of fonty commands
      :width: 760px
      :align: center

A command-line tool to download, manage and convert fonts
=========================================================

fonty is a command line interface that helps you simplify your font management
workflow by allowing you to install and uninstall fonts like a package manager
(think npm, apt-get, chocolatey). It can also help you create webfonts and
generate @font-face declarations so that you can focus on building great
websites.

For full documentation, visit the `GitHub page <https://github.com/jamesssooi/fonty/>`_.
